@@ -8,8 +8,9 @@ use Doctrine\Persistence\Mapping\ClassMetadata;
 use Doctrine\Persistence\Mapping\MappingException;
 
 use function array_keys;
+use function rtrim;
 use function spl_object_id;
-use function str_starts_with;
+use function strpos;
 
 /**
  * The DriverChain allows you to add multiple other mapping drivers for
@@ -56,7 +57,7 @@ class MappingDriverChain implements MappingDriver
     public function loadMetadataForClass(string $className, ClassMetadata $metadata): void
     {
         foreach ($this->drivers as $namespace => $driver) {
-            if (str_starts_with($className, $namespace)) {
+            if ($this->isInNamespace($className, $namespace)) {
                 $driver->loadMetadataForClass($className, $metadata);
 
                 return;
@@ -88,7 +89,7 @@ class MappingDriverChain implements MappingDriver
             }
 
             foreach ($driverClasses[$oid] as $className) {
-                if (! str_starts_with($className, $namespace)) {
+                if (! $this->isInNamespace($className, $namespace)) {
                     continue;
                 }
 
@@ -108,7 +109,7 @@ class MappingDriverChain implements MappingDriver
     public function isTransient(string $className): bool
     {
         foreach ($this->drivers as $namespace => $driver) {
-            if (str_starts_with($className, $namespace)) {
+            if ($this->isInNamespace($className, $namespace)) {
                 return $driver->isTransient($className);
             }
         }
@@ -119,4 +120,11 @@ class MappingDriverChain implements MappingDriver
 
         return true;
     }
+
+    private function isInNamespace(string $className, string $namespace): bool
+    {
+        $namespace = rtrim($namespace, '\\') . '\\';
+
+        return strpos($className, $namespace) === 0;
+    }
 }
