@@ -4,10 +4,8 @@ declare(strict_types=1);
 
 namespace Doctrine\Persistence\Reflection;
 
-use Doctrine\Common\Proxy\Proxy as CommonProxy;
 use Doctrine\Persistence\Proxy;
 use ReflectionProperty;
-use ReturnTypeWillChange;
 
 use function ltrim;
 use function method_exists;
@@ -20,9 +18,9 @@ use function method_exists;
  */
 class RuntimeReflectionProperty extends ReflectionProperty
 {
-    /** @var string */
-    private $key;
+    private readonly string $key;
 
+    /** @param class-string $class */
     public function __construct(string $class, string $name)
     {
         parent::__construct($class, $name);
@@ -30,13 +28,7 @@ class RuntimeReflectionProperty extends ReflectionProperty
         $this->key = $this->isPrivate() ? "\0" . ltrim($class, '\\') . "\0" . $name : ($this->isProtected() ? "\0*\0" . $name : $name);
     }
 
-    /**
-     * {@inheritDoc}
-     *
-     * @return mixed
-     */
-    #[ReturnTypeWillChange]
-    public function getValue($object = null)
+    public function getValue(object|null $object = null): mixed
     {
         if ($object === null) {
             return parent::getValue($object);
@@ -49,12 +41,8 @@ class RuntimeReflectionProperty extends ReflectionProperty
      * {@inheritDoc}
      *
      * @param object|null $object
-     * @param mixed       $value
-     *
-     * @return void
      */
-    #[ReturnTypeWillChange]
-    public function setValue($object, $value = null)
+    public function setValue(mixed $object, mixed $value = null): void
     {
         if (! ($object instanceof Proxy && ! $object->__isInitialized())) {
             parent::setValue($object, $value);
@@ -62,17 +50,6 @@ class RuntimeReflectionProperty extends ReflectionProperty
             return;
         }
 
-        if ($object instanceof CommonProxy) {
-            $originalInitializer = $object->__getInitializer();
-            $object->__setInitializer(null);
-
-            parent::setValue($object, $value);
-
-            $object->__setInitializer($originalInitializer);
-
-            return;
-        }
-
         if (! method_exists($object, '__setInitialized')) {
             return;
         }
