@@ -11,11 +11,15 @@ use Doctrine\Persistence\Mapping\MappingException;
 use Doctrine\Tests\DoctrineTestCase;
 use Doctrine\Tests\Persistence\Mapping\Fixtures\Manager\Manager;
 use Doctrine\Tests\Persistence\Mapping\Fixtures\Model;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\TestWith;
 use stdClass;
 
 class DriverChainTest extends DoctrineTestCase
 {
-    public function testDelegateToMatchingNamespaceDriver(): void
+    #[TestWith(['Doctrine\Tests\Models\Company'])]
+    #[TestWith(['Doctrine\Tests\Persistence\Map'])]
+    public function testDelegateToMatchingNamespaceDriver(string $namespace): void
     {
         $className     = DriverChainEntity::class;
         $classMetadata = $this->createMock(ClassMetadata::class);
@@ -37,7 +41,7 @@ class DriverChainTest extends DoctrineTestCase
                 ->with(self::equalTo($className))
                 ->willReturn(true);
 
-        $chain->addDriver($driver1, 'Doctrine\Tests\Models\Company');
+        $chain->addDriver($driver1, $namespace);
         $chain->addDriver($driver2, 'Doctrine\Tests\Persistence\Mapping');
 
         $chain->loadMetadataForClass($className, $classMetadata);
@@ -63,12 +67,12 @@ class DriverChainTest extends DoctrineTestCase
         $driver1 = $this->createMock(MappingDriver::class);
         $driver1->expects(self::once())
                 ->method('getAllClassNames')
-                ->will(self::returnValue(['Doctrine\Tests\Models\Company\Foo']));
+                ->willReturn(['Doctrine\Tests\Models\Company\Foo']);
 
         $driver2 = $this->createMock(MappingDriver::class);
         $driver2->expects(self::once())
                 ->method('getAllClassNames')
-                ->will(self::returnValue(['Doctrine\Tests\ORM\Mapping\Bar', 'Doctrine\Tests\ORM\Mapping\Baz', 'FooBarBaz']));
+                ->willReturn(['Doctrine\Tests\ORM\Mapping\Bar', 'Doctrine\Tests\ORM\Mapping\Baz', 'FooBarBaz']);
 
         $chain->addDriver($driver1, 'Doctrine\Tests\Models\Company');
         $chain->addDriver($driver2, 'Doctrine\Tests\ORM\Mapping');
@@ -80,7 +84,7 @@ class DriverChainTest extends DoctrineTestCase
         ], $chain->getAllClassNames());
     }
 
-    /** @group DDC-706 */
+    #[Group('DDC-706')]
     public function testIsTransient(): void
     {
         $driver1 = $this->createMock(MappingDriver::class);
@@ -90,7 +94,7 @@ class DriverChainTest extends DoctrineTestCase
         self::assertTrue($chain->isTransient(stdClass::class), 'stdClass isTransient');
     }
 
-    /** @group DDC-1412 */
+    #[Group('DDC-1412')]
     public function testDefaultDriver(): void
     {
         $companyDriver    = $this->createMock(MappingDriver::class);
@@ -104,14 +108,14 @@ class DriverChainTest extends DoctrineTestCase
         $companyDriver->expects(self::once())
             ->method('isTransient')
             ->with(self::equalTo($managerClassName))
-            ->will(self::returnValue(false));
+            ->willReturn(false);
 
         $defaultDriver->expects(self::never())
             ->method('loadMetadataForClass');
         $defaultDriver->expects(self::once())
             ->method('isTransient')
             ->with(self::equalTo($entityClassName))
-            ->will(self::returnValue(true));
+            ->willReturn(true);
 
         self::assertNull($chain->getDefaultDriver());
 
@@ -134,11 +138,11 @@ class DriverChainTest extends DoctrineTestCase
 
         $companyDriver->expects(self::once())
             ->method('getAllClassNames')
-            ->will(self::returnValue(['Doctrine\Tests\Models\Company\Foo']));
+            ->willReturn(['Doctrine\Tests\Models\Company\Foo']);
 
         $defaultDriver->expects(self::once())
             ->method('getAllClassNames')
-            ->will(self::returnValue(['Other\Class']));
+            ->willReturn(['Other\Class']);
 
         $chain->setDefaultDriver($defaultDriver);
         $chain->addDriver($companyDriver, 'Doctrine\Tests\Models\Company');
